@@ -24,7 +24,16 @@
         "\nhas to be manually specified. See ?seasonal for details."
       ))
     }
-    x13binary::checkX13binary(verbose = FALSE)
+    cc <- try(x13binary::checkX13binary(verbose = FALSE), silent = TRUE)
+    if (inherits(cc, "try-error")) {
+      return(mymsg(
+        "The binaries provided by 'x13binary' do not work on this", 
+        "\nmachine. To get more information, run:", 
+        "\n  x13binary::checkX13binary()", 
+        "\n\nYou can set 'X13_PATH' manually if you intend to use your own",
+        "\nbinaries. See ?seasonal for details.\n"
+      ))
+    }
     Sys.setenv(X13_PATH = x13binary::x13path())
   }
   checkX13(fullcheck = FALSE, htmlcheck = TRUE)
